@@ -53,10 +53,7 @@ class AttachmentsForObjectNode(Node):
 
     def render(self, context):
         obj = self.resolve(self.obj, context)
-        if self.var_name:
-            var_name = self.resolve(self.var_name, context)
-        else:
-            var_name = 'attachments'
+        var_name = self.resolve(self.var_name, context)
         context[var_name] = Attachment.objects.attachments_for_object(obj)
         return ''
 
@@ -86,6 +83,6 @@ def get_attachments_for(parser, token):
     bits = token.contents.split()
     args = {
         'obj': next_bit_for(bits, 'get_attachments_for'),
-        'var_name': next_bit_for(bits, 'as'),
+        'var_name': next_bit_for(bits, 'as', 'attachments'),
     }
     return AttachmentsForObjectNode(**args)
\ No newline at end of file
